Skip to contentSkip to conversation

boards/t2080rdb: update ddr frequency from 1600MT/s to 1867MT/s

PATCH New Shengzhou Liu 2 participants 2 messages Apr 1, 2015 – Apr 16, 2015

lore
Share & tools
lore
#0 lore raw

PATCH 1/1 boards/t2080rdb: update ddr frequency from 1600MT/s to 1867MT/s

T2080RDB RevC uses new SODIMM 1867MT/s instead of previous 1600MT/s.

So update RCW to support new DDR frequency i.e 1867MT/s

---
 board/freescale/t208xrdb/t2080_rcw.cfg | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
board/freescale/t208xrdb/t2080_rcw.cfg +2 -2
index 59025ea..7c55150 100644
@@ -9,8 +9,8 @@ aa55aa55 010e0100
 #00000000 00000000 00000000 00000004
 
 #For T2080 v1.1
-#SerDes=0x66_0x15, Core:1800MHz, DDR:1600MT/s
-1206001b 15000000 00000000 00000000
+#SerDes=0x66_0x15, Core:1800MHz, DDR:1867MT/s
+1207001b 15000000 00000000 00000000
 66150002 00000000 e8104000 c1000000
 00800000 00000000 00000000 000307fc
 00000000 00000000 00000000 00000004
Signature · 1 line
2.1.0.27.g96db324
#1 lore raw

PATCH 1/1 boards/t2080rdb: update ddr frequency from 1600MT/s to 1867MT/s

Shengzhou,

Quoted 3 lines · Shengzhou Liu

T2080RDB RevC uses new SODIMM 1867MT/s instead of previous 1600MT/s.

So update RCW to support new DDR frequency i.e 1867MT/s

This patch updates RCW. The subject is not clear.

Quoted 12 lines
---
 board/freescale/t208xrdb/t2080_rcw.cfg | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
board/freescale/t208xrdb/t2080_rcw.cfg +0 -0
index 59025ea..7c55150 100644

board/freescale/t208xrdb/t2080_rcw.cfg aa55aa55 010e0100 · line 16

Quoted 10 lines
board/freescale/t208xrdb/t2080_rcw.cfg +2 -2
@@ -9,8 +9,8 @@ aa55aa55 010e0100
 #00000000 00000000 00000000 00000004
 
 #For T2080 v1.1
-#SerDes=0x66_0x15, Core:1800MHz, DDR:1600MT/s
-1206001b 15000000 00000000 00000000
+#SerDes=0x66_0x15, Core:1800MHz, DDR:1867MT/s
+1207001b 15000000 00000000 00000000
 66150002 00000000 e8104000 c1000000
 00800000 00000000 00000000 000307fc
 00000000 00000000 00000000 00000004

Are previous version boards still in use? Maybe you should consider to keep the old value in comment so users can choose if needed?

York